@@ -121,7 +121,7 @@ use Data::Serializer;
 use Time::HiRes qw/ alarm sleep /;
 use File::Spec;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 extends 'Async::Simple::Task::Fork';
 
@@ -255,13 +255,21 @@ Makes child process and returns pid of child process to parent or 0 to child pro
 sub fork_child {
     my ( $self ) = @_;
 
-    my $randname = sub {
+    my( $randname, $parent_writer_fname, $parent_reader_fname );
+    $randname = sub {
         my @x = ( 'a'..'z', 'A'..'Z', 0..9 );
         join( "", map { $x[ int( rand @x - 0.01 ) ] } 1 .. 64 )
     };
 
-    my $parent_writer_fname = File::Spec->catfile( $self->tmp_dir, '_pw_tmp_' . $randname->() );
-    my $parent_reader_fname = File::Spec->catfile( $self->tmp_dir, '_pr_tmp_' . $randname->() );
+    for ( 1..10 ) {
+    	$parent_writer_fname = File::Spec->catfile( $self->tmp_dir, '_pw_tmp_' . $randname->() );
+    	$parent_reader_fname = File::Spec->catfile( $self->tmp_dir, '_pr_tmp_' . $randname->() );
+
+  	next if -f $parent_writer_fname || -f $parent_reader_fname;
+	last;
+    };
+
+    die 'Can`t obtain unique fname'  if -f $parent_writer_fname || -f $parent_reader_fname;
 
     my $pid = fork() // die "fork() failed: $!";
 
@@ -313,7 +321,12 @@ sub get {
 
     close( $fh );
 
-    unlink $self->reader;
+    # In case, when reader still opened for writing
+    # We are not allowed to remove file, so we should wait
+    for ( 1..10 ) {
+        last  if unlink $self->reader;
+	sleep $self->timeout;
+    }
 
     my $answer = $data
         ? eval{ $self->serializer->deserialize( $data )->[0] }
@@ -337,12 +350,18 @@ sub put {
     unlink $self->writer;
     $self->clear_answer;
 
+    my $save_flush = $|;
+    $| = 1;
+
     open( my $fh, '>', $self->writer );
 
     # Each pack starts with an empty line and serialized string of useful data
     say $fh $self->serializer->serialize( [ $data ] );
 
     close $fh;
+
+    $| = $save_flush;
+
 };
 
 
